powered by
Get 4th down plays from a game.
get_4th_plays(gid)
Original data frame Data frame plus the following columns added:
Play description from ESPN.
Play type text from ESPN.
Index number of play from a given game. Useful for tracking plays (e.g. for 4th down bot).
All the columns needed for add_4th_probs().
add_4th_probs().
A game to get 4th down decisions of.
Obtains a data frame that can be used with add_4th_probs(). The following columns must be present:
add_4th_probs()
game_id : game ID in nflfastR format (eg '2020_20_TB_GB')
# \donttest{ plays <- nfl4th::get_4th_plays('2020_20_TB_GB') dplyr::glimpse(plays) # }
Run the code above in your browser using DataLab